@@ -19,7 +19,7 @@ use version ();
 use constant BAD_TAR => ($^O eq 'solaris' || $^O eq 'hpux');
 use constant CAN_SYMLINK => eval { symlink("", ""); 1 };
 
-our $VERSION = '1.9021';
+our $VERSION = '1.9022';
 
 if ($INC{"App/FatPacker/Trace.pm"}) {
     require version::vpp;
@@ -462,12 +462,6 @@ sub with_version_range {
     defined($version) && $version =~ /(?:<|!=|==)/;
 }
 
-# version->new("1.00_00")->numify => "1.00_00" :/
-sub numify_ver {
-    my($self, $ver) = @_;
-    eval version->new($ver)->numify;
-}
-
 sub search_metacpan {
     my($self, $module, $version, $dev_release) = @_;
 
@@ -2094,7 +2088,7 @@ DIAG
         my $version = $dist->{module_version} || $dist->{meta}{version} || $dist->{version};
         my $reinstall = $local && ($local eq $version);
         my $action  = $local && !$reinstall
-                    ? $self->numify_ver($version) < $self->numify_ver($local)
+                    ? $self->is_downgrade($version, $local)
                         ? "downgraded"
                         : "upgraded"
                     : undef;
@@ -2115,6 +2109,11 @@ DIAG
     }
 }
 
+sub is_downgrade {
+    my($self, $va, $vb) = @_;
+    eval { version::->new($va) < $vb };
+}
+
 sub opts_in_static_install {
     my($self, $meta) = @_;
 
